@@ -1,8 +1,12 @@
-package Raisin::API;
+#!perl
+#PODNAME: Raisin::API
+#ABSTACT: Provides Raisin DSL.
 
 use strict;
 use warnings;
 
+package Raisin::API;
+$Raisin::API::VERSION = '0.90';
 use parent 'Exporter';
 
 use Carp;
@@ -243,9 +247,17 @@ sub error {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Raisin::API - Provides Raisin DSL.
+Raisin::API
+
+=head1 VERSION
+
+version 0.90
 
 =head1 DESCRIPTION
 
@@ -253,11 +265,13 @@ See L<Raisin>.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
