@@ -1,15 +1,19 @@
-package Raisin::Encoder::JSON;
+#!perl
+#PODNAME: Raisin::Encoder::JSON
+#ABSTRACT: JSON serialization plugin for Raisin.
 
 use strict;
 use warnings;
 
+package Raisin::Encoder::JSON;
+$Raisin::Encoder::JSON::VERSION = '0.90';
 use JSON::MaybeXS qw();
 
 my $json = JSON::MaybeXS->new(utf8 => 1);
 
 sub detectable_by { [qw(application/json text/x-json text/json json)] }
 
-sub content_type { 'application/json' }
+sub content_type { 'application/json; charset=utf-8' }
 
 sub serialize { $json->allow_blessed->convert_blessed->encode($_[1]) }
 
@@ -19,21 +23,31 @@ sub deserialize { $json->allow_blessed->convert_blessed->decode($_[1]) }
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Raisin::Encoder::JSON - JSON serialization plugin for Raisin.
 
+=head1 VERSION
+
+version 0.90
+
 =head1 DESCRIPTION
 
 Provides C<content_type>, C<serialize> methods.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
