@@ -1,8 +1,12 @@
-package Raisin::Encoder::Text;
+#!perl
+#PODNAME: Raisin::Encoder::Text
+#ABSTRACT: Data::Dumper serialization plugin for Raisin.
 
 use strict;
 use warnings;
 
+package Raisin::Encoder::Text;
+$Raisin::Encoder::Text::VERSION = '0.90';
 use Data::Dumper;
 use Encode 'encode';
 
@@ -31,21 +35,31 @@ sub deserialize {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Raisin::Encoder::Text - Data::Dumper serialization plugin for Raisin.
 
+=head1 VERSION
+
+version 0.90
+
 =head1 DESCRIPTION
 
 Provides C<content_type>, C<serialize> methods.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
