@@ -1,8 +1,12 @@
-package Raisin::Entity;
+#!perl
+#PODNAME: Raisin::Entity
+#ABSTRACT: A simple facade to use with your API
 
 use strict;
 use warnings;
 
+package Raisin::Entity;
+$Raisin::Entity::VERSION = '0.90';
 use parent 'Exporter';
 
 use Carp;
@@ -174,9 +178,17 @@ sub _make_exposition {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Raisin::Entity - A simple facade to use with your API.
+Raisin::Entity - A simple facade to use with your API
+
+=head1 VERSION
+
+version 0.90
 
 =head1 SYNOPSIS
 
@@ -287,11 +299,13 @@ plugin enabled.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
