@@ -1,8 +1,12 @@
-package Raisin::Logger;
+#!perl
+#PODNAME: Raisin::Logger
+#ABSTRACT: Default logger for Raisin.
 
 use strict;
 use warnings;
 
+package Raisin::Logger;
+$Raisin::Logger::VERSION = '0.90';
 my $FH = *STDERR;
 
 sub new { bless {}, shift }
@@ -16,10 +20,18 @@ sub log {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Raisin::Logger - Default logger for Raisin.
 
+=head1 VERSION
+
+version 0.90
+
 =head1 SYNOPSIS
 
     my $logger = Raisin::Logger->new;
@@ -37,11 +49,13 @@ Accept's two parameters: C<level> and C<message>.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
