@@ -1,8 +1,12 @@
-package Raisin::Param;
+#!perl
+#PODNAME: Raisin::Param
+#ABSTRACT: Parameter class for Raisin
 
 use strict;
 use warnings;
 
+package Raisin::Param;
+$Raisin::Param::VERSION = '0.90';
 use Carp;
 use Plack::Util::Accessor qw(
     named
@@ -161,9 +165,17 @@ sub validate {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Raisin::Param - Parameter class for Raisin.
+Raisin::Param - Parameter class for Raisin
+
+=head1 VERSION
+
+version 0.90
 
 =head1 DESCRIPTION
 
@@ -219,11 +231,13 @@ Process and validate parameter. Takes B<reference> as the input paramter.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
