@@ -1,8 +1,13 @@
-package Raisin::Plugin::Swagger;
+#!perl
+#PODNAME: Raisin::Plugin::Swagger
+#ABSTRACT: Generates API description in Swagger 2/OpenAPI compatible format
+# vim:ts=4:shiftwidth=4:expandtab:syntax=perl
 
 use strict;
 use warnings;
 
+package Raisin::Plugin::Swagger;
+$Raisin::Plugin::Swagger::VERSION = '0.90';
 use parent 'Raisin::Plugin';
 
 use Carp 'croak';
@@ -87,7 +92,10 @@ sub _spec_20 {
         : qw(application/x-yaml application/json);
 
     my $base_path = $req->base->as_string;
-    $base_path =~ s#http(?:s?)://[^/]+##msix;
+    ### Respect proxied requests
+    #   A proxy map is used to fill the "basePath" attribute.
+    my $_base = $req->env->{HTTP_X_FORWARDED_SCRIPT_NAME} || q(/);
+    $base_path =~ s#http(?:s?)://[^/]+/#$_base#msix;
 
     $DEFAULTS{consumes} = \@content_types;
     $DEFAULTS{produces} = \@content_types;
@@ -95,7 +103,11 @@ sub _spec_20 {
     my %spec = (
         swagger => '2.0',
         info => _info_object($app),
-        host => $req->env->{SERVER_NAME} || $req->env->{HTTP_HOST},
+        ### Respect proxied requests
+        #   The frontend hostname is used if set.
+        host => $req->env->{HTTP_X_FORWARDED_HOST}
+            || $req->env->{SERVER_NAME}
+            || $req->env->{HTTP_HOST},
         basePath => $base_path,
         schemes => [$req->scheme],
         consumes => \@content_types,
@@ -390,34 +402,51 @@ sub _param_type_object {
     my $p = shift;
     my %item;
 
-    if (_type_name($p->type) =~ /^HashRef$/ ) {
+    my $tt = $p->type;
+
+
+    if (_type_name($tt) =~ /^Maybe\[/) {
+    $item{nullable} = JSON::MaybeXS::true;
+        $tt = $tt->type_parameter;
+    }
+
+    if (_type_name($tt) =~ /^HashRef$/ ) {
         $item{'$ref'} = sprintf('#/definitions/%s', _name_for_object($p->can('using')?$p->using:$p));
     }
-    elsif (_type_name($p->type) =~ /^HashRef\[.*\]$/) {
+    elsif (_type_name($tt) =~ /^HashRef\[.*\]$/) {
         $item{'type'} = 'object';
         $item{'additionalProperties'} = {
                             '$ref' => sprintf('#/definitions/%s', _name_for_object($p->using))
                             };
     }
-    elsif (_type_name($p->type) =~ /^ArrayRef/) {
+    elsif (_type_name($tt) =~ /^ArrayRef/) {
         $item{type} = 'array';
 
         my $type;
         my $format;
 
-        if($p->type->can('type_parameter')) {
-            ($type, $format) = _param_type($p->type->type_parameter);
-        }
-        else {
-            ($type, $format) = ('object', '' );
+        # Loop down to find type beneath coercion.
+        while (!defined $type) {
+            if($tt->can('type_parameter')) {
+                ($type, $format) = _param_type($tt->type_parameter);
+            }
+            else {
+                ($type, $format) = ('object', '' );
+            }
+            $tt = $tt->parent if !defined $type;
         }
 
         if ($type eq 'object') {
+            $item{items} = {}; # {} is the "any-type" schema.
             if ($p->can('using') && $p->using) {
                 $item{items}{'$ref'} = sprintf('#/definitions/%s', _name_for_object($p->using));
             }
-            else {
-                $item{items} = {}; # {} is the "any-type" schema.
+            elsif ($tt->can("type_parameter")) {
+               my ($subscript_type, $subscript_format) = _param_type($tt->type_parameter);
+               if (defined $subscript_type) {
+                  $item{items}->{type}   = $subscript_type;
+                  $item{items}->{format} = $subscript_format if defined $subscript_format;
+               }
             }
         }
         else {
@@ -427,7 +456,7 @@ sub _param_type_object {
         }
     }
     else {
-        my ($type, $format) = _param_type($p->type);
+        my ($type, $format) = _param_type($tt);
         $item{type} = $type;
         $item{format} = $format if $format;
         $item{description} = $p->desc if $p->desc;
@@ -489,9 +518,17 @@ sub _type_is_enum {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Raisin::Plugin::Swagger - Generates API description in Swagger 2/OpenAPI compatible format.
+Raisin::Plugin::Swagger - Generates API description in Swagger 2/OpenAPI compatible format
+
+=head1 VERSION
+
+version 0.90
 
 =head1 SYNOPSIS
 
@@ -631,11 +668,13 @@ For more information please check OpenAPI specification and L<Raisin::Plugin::Sw
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
