@@ -1,8 +1,12 @@
-package Raisin::Request;
+#!perl
+#PODNAME: Raisin::Request
+#ABSTRACT: Request class for Raisin.
 
 use strict;
 use warnings;
 
+package Raisin::Request;
+$Raisin::Request::VERSION = '0.90';
 use parent 'Plack::Request';
 
 sub prepare_params {
@@ -49,10 +53,18 @@ sub raisin_parameters { shift->{'raisin.parameters'} }
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Raisin::Request - Request class for Raisin.
 
+=head1 VERSION
+
+version 0.90
+
 =head1 SYNOPSIS
 
     Raisin::Request->new($self, $env);
@@ -71,11 +83,13 @@ Extends L<Plack::Request>.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin <rtkh@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This module and all the modules in this package are governed by the same license
-as Perl itself.
+This software is copyright (c) 2019 by Artur Khabibullin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
